@@ -4,17 +4,17 @@ import argparse
 import json
 import smtplib
 import socket
-import urllib.parse
 import sys
-from logging import warning
+import urllib.parse
 from email.mime.text import MIMEText
+from logging import warning
 from typing import Any, Optional
 
-
+import act.api
 import requests
 import urllib3
-
-import act.api
+from act.types.format import object_format
+from act.types.types import object_validates
 
 
 class FetchError(Exception):
@@ -59,6 +59,13 @@ class ServiceTimeout(Exception):
         Exception.__init__(self, *args)
 
 
+class AuthenticationError(Exception):
+    """Authentication Errors"""
+
+    def __init__(self, *args: Any) -> None:
+        Exception.__init__(self, *args)
+
+
 def parseargs(description: str) -> argparse.ArgumentParser:
     """Parse arguments"""
 
@@ -77,7 +84,11 @@ def init_act(args: argparse.Namespace) -> act.api.Act:
 
     """Initialize act api from arguments"""
 
-    api = act.api.libs.cli.init_act(args)
+    api = act.api.libs.cli.init_act(
+        args,
+        object_formatter=object_format,
+        object_validator=object_validates,
+    )
 
     # This check is done here to make sure logging is set up
     if args.disabled:
